==> linktocontent-5.x-1.0.tar.gz: linktocontent/tinymce_plugins/linktomenu/jscripts/functions.js <==
// $Id: functions.js,v 1.1.2.2 2007/03/07 08:35:24 stborchert Exp $

function preinit() {
	// Initialize
	tinyMCE.setWindowArg('mce_windowresize', false);
}

function init() {
  // load additional scripts
  loadScript("jscripts/options.js");
  loadScript("jscripts/dropdown.js");
  loadScript("jscripts/nodelist.js");
  window.focus();
  loadCategories(null);
}

/**
 * loadCategories()
 * @param obj parent Object
 **/
function loadCategories(obj) {
  var params = '';
  var mid = '0';
  var top = 75;
  var objTop;
  if (obj != null) {
    var fSel = $(obj);
    mid = fSel.get(0).value;

    try
    {
      objTop = $(obj).id().match(/_(\d+)_sel/);
      top += (objTop[1] * 17);
    }
    catch (e) {
      top += 0;
    }
  }
  params = 'ltc-type=linktocontent_menu&ltc-menu-id=' + mid;

  $("#statusImg").top(top + "px").show();

  $.ajax({
    type: "POST",
    url: _getBaseHref() + '?q=linktocontent',
    data: params,
    error: function(xml, msg, exc) {
      alert('Error: ' + msg);
    },
    success: function(data){
      var results = eval('(' + data + ');');
      _clearNodeList();
      if ((obj == null) || ($(obj).get(0).value > -1)) {
        if (_fillDropdown(obj, results)) {
          window.resizeBy( 0, 17 );
        }
      }
      _fillNodelist(results);
      $("#statusImg").hide();
    }});
}

function insertAction() {
  if (selectedNode == null) {
    return;
  }
	var inst = tinyMCE.getInstanceById(tinyMCE.getWindowArg('editor_id'));
	var elm = inst.getFocusElement();

	elm = tinyMCE.getParentElement(elm, "a");

	tinyMCEPopup.execCommand("mceBeginUndoLevel");

	// Create new anchor elements
	var path = selectedNode.cells[0].firstChild.nodeValue;
	if (elm == null) {
		var insertText = selectedNode.cells[1].firstChild.nodeValue;
    if (inst.selection.getSelectedText().length == 0) {
      tinyMCEPopup.execCommand("mceInsertContent", false,
        '<a href="' + path + '">' + insertText + '</a>');
		}
    else {
   	  tinyMCEPopup.execCommand("mceInsertContent", false,
        '<a href="' + path + '">' + inst.selection.getSelectedHTML() + '</a>');
    } // end (getSelectedText == 0)
	}
  else {
    elm.setAttribute("mce_href", path);
  	// Refresh in old MSIE
  	if (tinyMCE.isMSIE5)
  		elm.outerHTML = elm.outerHTML;
	}

	tinyMCE._setEventsEnabled(inst.getBody(), false);
	tinyMCEPopup.execCommand("mceEndUndoLevel");
	tinyMCEPopup.close();
}

function loadScript(url) {
  var script = document.createElement("script");
  script.type = "text/javascript";
  script.src = url;
  $("head", document).append(script);
}


/**
 * returns the base drupal path
 * @access public
 **/
function _getBaseHref() {
  var url = tinyMCE.baseURL.substring(0, tinyMCE.baseURL.indexOf('modules/'));
  if (url.indexOf('sites/') > -1)
    url = url.substring(0, url.indexOf('sites/'));
  return url;
}

==> linktocontent-5.x-1.3.tar.gz: linktocontent/tinymce_plugins/linktomenu/jscripts/functions.js <==
// $Id: functions.js,v 1.1.2.4 2007/06/03 10:34:32 stborchert Exp $

function preinit() {
	// Initialize
	tinyMCE.setWindowArg('mce_windowresize', false);
}

function init() {
  // load additional scripts
  loadScript('jscripts/options.js');
  loadScript('jscripts/dropdown.js');
  loadScript('jscripts/nodelist.js');
  window.focus();
  loadCategories(null);
}

/**
 * loadCategories()
 * @param obj parent Object
 **/
function loadCategories(obj) {
  var params = '';
  var mid = '0';
  var top = 75;
  var objTop;
  if (obj != null) {
    mid = $(obj).get(0).value;

    try
    {
      objTop = $(obj).attr('id').match(/_(\d+)_sel/);
      top += (objTop[1] * 17);
    }
    catch (e) {
      top += 0;
    }
  }
  params = 'ltc-type=linktocontent_menu&ltc-menu-id=' + mid;

  $('#statusImg').css({top: top + 'px'}).show();

  $.ajax({
    type: "POST",
    url: _getBaseHref() + 'index.php?q=linktocontent',
    data: params,
    error: function(xml, msg, exc) {
      $('#statusImg').hide();
      alert('Error: ' + msg + '\n' + xml.responseText);
    },
    success: function(data){
      try {
        var results = eval('(' + data + ');');
        _clearNodeList();
        if ((obj == null) || ($(obj).get(0).value > -1)) {
          if (_fillDropdown($(obj), results)) {
            window.resizeBy( 0, 17 );
          }
        }
        _fillNodelist(results);
      }
      catch (e) {
        alert('Error on retrieving data from module.\n' + e.name + '\n' + e.message);
      } 
      finally {
        $('#statusImg').hide();
      }
    }});
}

function insertAction() {
  if (selectedNode == null) {
    return;
  }
	var inst = tinyMCE.getInstanceById(tinyMCE.getWindowArg('editor_id'));
	var elm = inst.getFocusElement();

	elm = tinyMCE.getParentElement(elm, "a");

	tinyMCEPopup.execCommand("mceBeginUndoLevel");

	// Create new anchor elements
	var path = selectedNode.cells[0].firstChild.nodeValue;
	if (elm == null) {
		var insertText = selectedNode.cells[1].firstChild.nodeValue;
    if (inst.selection.getSelectedText().length == 0) {
      tinyMCEPopup.execCommand("mceInsertContent", false,
        '<a href="' + path + '">' + insertText + '</a>');
		}
    else {
   	  tinyMCEPopup.execCommand("mceInsertContent", false,
        '<a href="' + path + '">' + inst.selection.getSelectedHTML() + '</a>');
    } // end (getSelectedText == 0)
	}
  else {
    elm.setAttribute("mce_href", path);
  	// Refresh in old MSIE
  	if (tinyMCE.isMSIE5)
  		elm.outerHTML = elm.outerHTML;
	}

	tinyMCE._setEventsEnabled(inst.getBody(), false);
	tinyMCEPopup.execCommand("mceEndUndoLevel");
	tinyMCEPopup.close();
}

function loadScript(url) {
  $('head', document).append('<script type="text/javascript" src="' + url + '"></script>');
}

/**
 * returns the base drupal path
 * @access public
 **/
function _getBaseHref() {
  var url = tinyMCE.baseURL.substring(0, tinyMCE.baseURL.indexOf('modules/'));
  if (url.indexOf('sites/') > -1)
    url = url.substring(0, url.indexOf('sites/'));
  return url;
}
